@@ -3,7 +3,7 @@
  * DATABASE.C
  *
  * Copyright 1994 Matthew Dillon (dillon@apollo.backplane.com)
- * Copyright 2009 James Pryor <profjim@jimpryor.net>
+ * Copyright 2009-2011 James Pryor <profjim@jimpryor.net>
  * May be distributed under the GNU General Public License
  */
 
@@ -236,7 +236,7 @@ ReadTimestamps(const char *user)
 	FILE *fi;
 	char buf[SMALL_BUFFER];
 	char *ptr;
-	struct tm tm = {0}; /* stop valgrind complaining */
+	struct tm tm = {0};
 	time_t sec, freq;
 
 	file = FileBase;
@@ -258,6 +258,7 @@ ReadTimestamps(const char *user)
 							if (ptr && (*ptr == 0 || *ptr == '\n'))
 								/* strptime uses current seconds when seconds not specified? anyway, we don't get round minutes */
 								tm.tm_sec = 0;
+								tm.tm_isdst = -1;
 								sec = mktime(&tm);
 							if (sec == (time_t)-1) {
 								printlogf(LOG_ERR, "unable to parse timestamp (user %s job %s)\n", file->cf_UserName, line->cl_JobName);
@@ -410,8 +411,10 @@ SynchronizeFile(const char *dpath, const char *fileName, const char *userName)
 								break;
 							case 5:
 								line.cl_Freq = MONTHLY_FREQ;
+								break;
 							case 6:
 								line.cl_Freq = YEARLY_FREQ;
+								break;
 							/* else line.cl_Freq will remain 0 */
 						}
 					}
@@ -996,7 +999,7 @@ TestJobs(time_t t1, time_t t2)
 				if (file->cf_Deleted)
 					continue;
 				for (line = file->cf_LineBase; line; line = line->cl_Next) {
-					if (line->cl_Pid != -1 && (line->cl_Freq == 0 || (line->cl_Freq > 0 && t2 >= line->cl_NotUntil))) {
+					if ((line->cl_Pid == -2 || line->cl_Pid == 0) && (line->cl_Freq == 0 || (line->cl_Freq > 0 && t2 >= line->cl_NotUntil))) {
 						/* (re)schedule job? */
 						if (line->cl_Mins[tp->tm_min] &&
 								line->cl_Hrs[tp->tm_hour] &&
