@@ -3,7 +3,7 @@
  * DEFS.H
  *
  * Copyright 1994-1998 Matthew Dillon (dillon@backplane.com)
- * Copyright 2009 James Pryor <profjim@jimpryor.net>
+ * Copyright 2009-2011 James Pryor <profjim@jimpryor.net>
  * May be distributed under the GNU General Public License
  */
 
@@ -51,10 +51,10 @@
 #define SCRONTABS	"/etc/cron.d"
 #endif
 #ifndef CRONTABS
-#define CRONTABS	"/var/spool/cron"
+#define CRONTABS	"/var/spool/cron/crontabs"
 #endif
 #ifndef CRONSTAMPS
-#define CRONSTAMPS	"/var/spool/cronstamps"
+#define CRONSTAMPS	"/var/spool/cron/cronstamps"
 #endif
 #ifndef LOG_IDENT
 #define LOG_IDENT	"crond"
